@@ -4,6 +4,6 @@ from .views import SwitchViewSet
 
 
 router = routers.DefaultRouter()
-router.register(r'switches', SwitchViewSet)
+router.register(r'', SwitchViewSet)
 
 urlpatterns = router.urls
